"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tall = void 0;
const url_1 = require("url");
const http_1 = require("http");
const https_1 = require("https");
const defaultOptions = {
    method: 'GET',
    maxRedirects: 3,
    headers: {}
};
const tall = (url, options) => {
    const opt = Object.assign({}, defaultOptions, options);
    return new Promise((resolve, reject) => {
        try {
            const { protocol, host } = new url_1.URL(url);
            let [, port] = host.split(':', 2);
            if (typeof port === 'undefined') {
                // if no port is specified set the port based on protocol
                port = protocol === 'https:' ? '443' : '80';
            }
            const method = opt.method;
            const request = protocol === 'https:' ? https_1.request : http_1.request;
            const headers = opt.headers;
            return request(url, { method, headers }, response => {
                if (response.headers.location && opt.maxRedirects) {
                    opt.maxRedirects--;
                    return resolve(exports.tall(response.headers.location.startsWith('http')
                        ? response.headers.location
                        : `${protocol}//${host}${response.headers.location}`, opt));
                }
                resolve(url);
            })
                .on('error', reject)
                .end();
        }
        catch (err) {
            return reject(err);
        }
    });
};
exports.tall = tall;
//# sourceMappingURL=index.js.map